@@ -1,5 +1,5 @@
 print('команды: help(1)')
-def help(f):
+def helpanite(f):
     with open('pyp.txt',encoding='ANSI') as f:
         line = f.readline()
         file = open("copy.txt", "w") 
